==> psylla_0.21.1.orig.tar.gz: psylla-0.21.1/src/main/java/coneforest.psylla/coneforest/psylla/core/PsyRange.java <==
package coneforest.psylla.core;

import coneforest.psylla.*;
import java.util.Iterator;
import java.util.Spliterators;
import java.util.stream.Stream;
import java.util.stream.StreamSupport;

/**
*	The representation of {@code range}.
*/
@Type("range")
public class PsyRange
	implements PsyFormalStream<PsyRealNumeric>
{

	public PsyRange(final PsyRealNumeric oInitial,
			final PsyRealNumeric oIncrement,
			final PsyRealNumeric oLimit)
	{
		this.oInitial=oInitial;
		this.oIncrement=oIncrement;
		this.oLimit=oLimit;
	}

	@Override
	public Stream<PsyRealNumeric> stream()
	{
		final boolean forward=oIncrement.psyGt(PsyInteger.ZERO).booleanValue();
		return StreamSupport.<PsyRealNumeric>stream(
				Spliterators.<PsyRealNumeric>spliteratorUnknownSize(
					new Iterator<PsyRealNumeric>()
						{
							@Override
							public boolean hasNext()
							{
								return (forward?
										oNext.psyLe(oLimit):
										oNext.psyGe(oLimit)).booleanValue();
							}

							@Override
							public PsyRealNumeric next()
							{
								oCurrent=oNext;
								oNext=(PsyRealNumeric)oCurrent.psyAdd(oIncrement);
								return oCurrent;
							}

							private PsyRealNumeric oCurrent;
							private PsyRealNumeric oNext=oInitial;
						}, 0),
					false);
	}

	@Override
	public String toSyntaxString()
	{
		return '%'+typeName()
			+'='+oInitial.toSyntaxString()
			+';'+oIncrement.toSyntaxString()
			+';'+oLimit.toSyntaxString()
			+'%';
	}

	private final PsyRealNumeric oInitial, oIncrement, oLimit;

	/**
	*	Context action of the {@code range} operator.
	*/
	@OperatorType("range")
	public static final ContextAction PSY_RANGE
		=ContextAction.<PsyRealNumeric, PsyRealNumeric, PsyRealNumeric>ofTriFunction(PsyRange::new);
}

==> psylla_0.22.1.orig.tar.gz: psylla-0.22.1/src/main/java/coneforest.psylla/coneforest/psylla/core/PsyRange.java <==
package coneforest.psylla.core;

import coneforest.psylla.runtime.*;
import java.util.Iterator;
import java.util.Spliterators;
import java.util.stream.Stream;
import java.util.stream.StreamSupport;

/**
*	The representation of {@code range}.
*/
@Type("range")
public class PsyRange
	implements PsyFormalStream<PsyRealNumeric>
{

	/**
	*	Context action of the {@code range} operator.
	*/
	@OperatorType("range")
	public static final ContextAction PSY_RANGE
		=ContextAction.<PsyRealNumeric, PsyRealNumeric, PsyRealNumeric>ofTriFunction(PsyRange::new);

	private final PsyRealNumeric oInitial, oIncrement, oLimit;

	public PsyRange(final PsyRealNumeric oInitial,
			final PsyRealNumeric oIncrement,
			final PsyRealNumeric oLimit)
	{
		this.oInitial=oInitial;
		this.oIncrement=oIncrement;
		this.oLimit=oLimit;
	}

	@Override
	public Stream<PsyRealNumeric> stream()
	{
		final boolean forward=oIncrement.compareTo(PsyInteger.ZERO)>0;
		return StreamSupport.<PsyRealNumeric>stream(
				Spliterators.<PsyRealNumeric>spliteratorUnknownSize(
					new Iterator<PsyRealNumeric>()
						{
							private PsyRealNumeric oCurrent;
							private PsyRealNumeric oNext=oInitial;

							@Override
							public boolean hasNext()
							{
								return forward?
										oNext.compareTo(oLimit)<=0:
										oNext.compareTo(oLimit)>=0;
							}

							@Override
							public PsyRealNumeric next()
							{
								oCurrent=oNext;
								oNext=oCurrent.psyAdd(oIncrement);
								return oCurrent;
							}
						}, 0),
					false);
	}

	@Override
	public String toSyntaxString()
	{
		return '%'+typeName()
			+'='+oInitial.toSyntaxString()
			+';'+oIncrement.toSyntaxString()
			+';'+oLimit.toSyntaxString()
			+'%';
	}
}
